@@ -1,6 +1,5 @@
 // SPDX-FileCopyrightText: 2021 Linus Jahn <lnj@kaidan.im>
 // SPDX-FileCopyrightText: 2023 Joshua Goins <josh@redstrate.com>
-//
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "abstractapi.h"
@@ -45,12 +44,6 @@ void AbstractApi::setCredentials(const Credentials &credentials)
     Q_EMIT credentialsChanged();
 }
 
-void AbstractApi::setCredentials(const QString &apiInstance)
-{
-    m_credentials = Credentials();
-    Q_EMIT credentialsChanged();
-}
-
 QNetworkAccessManager *AbstractApi::net() const
 {
     return m_netManager;
